
function [I, map] = imagein1(path)
%IMAGEIN1 Read image in from current-working or specified directory.
%   I = IMAGEIN1 displays a window containing all the files in the
%   current directory, and saves in I the image selected from the  
%   current directory. 
%   [I, MAP] = IMAGEIN1 variable MAP is required to be an output 
%   argument when the image being read is an indexed image.
%   [ . . .] = IMAGEIN1('PATH') is used when the image to be read 
%   resides in a specified directory. For example, the input
%   argument 'C:\MY_WORK\MY_IMAGES' opens a window showing 
%   the contents of directory MY_IMAGES. An image selected from
%   that directory is read in as image I.

%   Copyright 2009 R. C. Gonzalez, R. E. Woods, & S. L. Eddins
%   For use with Digital Image Processing Using MATLAB, 2nd ed.
%   Gatesmark Publishing, 2009.
%   $Revision: 1.1 $  $Date: 2009/03/15 00:20:44 $

if nargin < 1
   path = pwd;
end

original_directory = pwd; % Save the current working directory.
cd(path); % Change current directory to specified directory.

% Read image from current directory.
[file, pathname] = uigetfile('*.*', 'Image Open');
cd(pathname);
if isequal(file, 0) | isequal(pathname, 0)
   disp('Image input canceled.');
   I = [];
   map = [];
else
   [I, map] = imread(file);   
end

% Change back to the original working directory.
cd(original_directory);
